@@ -9,9 +9,8 @@ pub mod ddcl_submit;
 
 use anyhow::{Result, bail};
 use hyper::{Body, Client, Method, Request};
-use hyper_tls::HttpsConnector;
 use futures::StreamExt;
-use crate::ddinfo::models::{DdstatsRustIntegration, Entry, Leaderboard, SpawnsetFile, SpawnsetForDdcl};
+use crate::{ddinfo::models::{DdstatsRustIntegration, Entry, Leaderboard, SpawnsetFile, SpawnsetForDdcl}, client_https};
 
 use self::models::{OperatingSystem, MarkerResponse, Tool};
 
@@ -33,8 +32,7 @@ pub fn time_as_int(t: f32) -> i32 {
 //////////////////////////////////
 
 pub async fn get_ddstats_memory_marker(os: OperatingSystem) -> Result<MarkerResponse> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/process-memory/marker?operatingSystem={:?}", os);
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -59,8 +57,7 @@ pub async fn get_ddstats_memory_marker(os: OperatingSystem) -> Result<MarkerResp
 //////////////////////////////////
 
 pub async fn get_tool<T: ToString>(tool_name: T) -> Result<Tool> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/tools/{}", tool_name.to_string());
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -85,8 +82,7 @@ pub async fn get_tool<T: ToString>(tool_name: T) -> Result<Tool> {
 //////////////////////////////////
 
 pub async fn get_integration_ddstats_rust() -> Result<DdstatsRustIntegration> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = "api/integrations/ddstats-rust".to_string();
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -111,8 +107,7 @@ pub async fn get_integration_ddstats_rust() -> Result<DdstatsRustIntegration> {
 //////////////////////////////////
 
 pub async fn get_leaderboard(rank_start: i32) -> Result<Leaderboard> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/leaderboards?rankStart={}", rank_start);
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -134,8 +129,7 @@ pub async fn get_leaderboard(rank_start: i32) -> Result<Leaderboard> {
 }
 
 pub async fn get_leaderboard_user_by_id(uid: i32) -> Result<Entry> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/leaderboards/entry/by-id?id={}", uid);
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -157,8 +151,7 @@ pub async fn get_leaderboard_user_by_id(uid: i32) -> Result<Entry> {
 }
 
 pub async fn get_leaderboard_user_by_username<T: ToString>(username: T) -> Result<Vec<Entry>>{
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/leaderboards/entry/by-username?username={}", username.to_string());
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -180,8 +173,7 @@ pub async fn get_leaderboard_user_by_username<T: ToString>(username: T) -> Resul
 }
 
 pub async fn get_leaderboard_user_by_rank(rank: i32) -> Result<Entry> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/leaderboards/entry/by-rank?rank={}", rank);
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -206,8 +198,7 @@ pub async fn get_leaderboard_user_by_rank(rank: i32) -> Result<Entry> {
 //////////////////////////////////
 
 pub async fn get_all_spawnsets<T: ToString, K: ToString>(name_filter: T, author_filter: K) -> Result<Vec<SpawnsetFile>> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/spawnsets/ddse?authorFilter={}&nameFilter={}", author_filter.to_string(), name_filter.to_string());
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
@@ -229,8 +220,7 @@ pub async fn get_all_spawnsets<T: ToString, K: ToString>(name_filter: T, author_
 }
 
 pub async fn get_spawnset_by_hash<T: ToString>(hash: T) -> Result<SpawnsetForDdcl> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let vv = crate::utils::decode_hex(&hash.to_string())?;
     let b = base64::encode(vv)
         .replace('=', "%3D")
@@ -260,8 +250,7 @@ pub async fn get_spawnset_by_hash<T: ToString>(hash: T) -> Result<SpawnsetForDdc
 //////////////////////////////////
 
 pub async fn custom_leaderboard_exists<T: ToString>(hash: T) -> Result<()> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let vv = crate::utils::decode_hex(&hash.to_string())?;
     let b = base64::encode(vv)
         .replace('=', "%3D")
@@ -286,8 +275,7 @@ pub async fn custom_leaderboard_exists<T: ToString>(hash: T) -> Result<()> {
 }
 
 pub async fn get_replay_by_id(entry_id: i32) -> Result<Vec<u8>> {
-    let https = HttpsConnector::new();
-    let client = Client::builder().build::<_, hyper::Body>(https);
+    let client = client_https!();
     let path = format!("api/custom-entries/{}/replay", entry_id);
     let uri = format!("https://devildaggers.info/{}", path);
     let req = Request::builder()
